﻿using System;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Windows;
using System.Windows.Forms;
using Telerik.Windows.Documents.Flow.FormatProviders.Docx;
using Telerik.Windows.Documents.Flow.Model;
using Telerik.Windows.Documents.Flow.Model.Editing;
using Telerik.Windows.Documents.Flow.Model.Lists;
using Telerik.Windows.Documents.Flow.Model.Shapes;
using Telerik.Windows.Documents.Flow.Model.Styles;
using Telerik.Windows.Documents.Media;
using Telerik.Windows.Documents.Model;
using Telerik.Windows.Documents.Spreadsheet.Model;
using WordsProcessingBlogPart1.Properties;

namespace WordsProcessingBlogPart1
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void radButton1_Click(object sender, EventArgs e)
        {
            #region Document
            
            RadFlowDocument document = new RadFlowDocument();
            RadFlowDocumentEditor editor = new RadFlowDocumentEditor(document);
            
            Section section = new Telerik.Windows.Documents.Flow.Model.Section(document);
            document.Sections.Add(section);
           
            section.PageMargins = new Telerik.Windows.Documents.Primitives.Padding(40, 10, 40, 10);
            section.PageSize = PaperTypeConverter.ToSize(PaperTypes.A4);//WindowsBase assembly should be referenced.

            #endregion

            #region Header

            Header defaultHeader = document.Sections.First().Headers.Add();
            
            Paragraph defaultHeaderParagraph = defaultHeader.Blocks.AddParagraph();
            defaultHeaderParagraph.TextAlignment = Alignment.Left;
            
            Run title = defaultHeaderParagraph.Inlines.AddRun("Job Openings");
            title.FontSize = 27;                  
            //the presentation core assembly references required for the following properties.
            title.ForegroundColor = new ThemableColor(System.Windows.Media.Colors.DarkBlue);
            title.FontFamily = new ThemableFontFamily("Felix Titling");
            
            FloatingImage logo = defaultHeaderParagraph.Inlines.AddFloatingImage();
            using (MemoryStream ms = new MemoryStream())
            {
                Resources.logo.Save(ms, System.Drawing.Imaging.ImageFormat.Png);
                logo.Image.ImageSource = new ImageSource(ms, "png");
            }
            logo.Image.Width = 200;
            logo.Image.Height = 72;
            
            logo.HorizontalPosition.ValueType = PositionValueType.Alignment;
            logo.VerticalPosition.ValueType = PositionValueType.Alignment;
            
            logo.VerticalPosition.Alignment = RelativeVerticalAlignment.Top;
            logo.HorizontalPosition.Alignment = RelativeHorizontalAlignment.Right;
            
            #endregion
            
            #region List
            
            List list = new List();
            
            document.Lists.Add(list);
            
            list.Levels[0].StartIndex = 1;          
            list.Levels[0].NumberingStyle = NumberingStyle.Decimal;
            list.Levels[0].NumberTextFormat = 1 + ".";
            
            list.Levels[1].StartIndex = 1;
            list.Levels[1].NumberingStyle = NumberingStyle.Decimal;
            list.Levels[1].NumberTextFormat = 2 + ".";
            
            list.Levels[2].StartIndex = 1;
            list.Levels[2].NumberingStyle = NumberingStyle.Decimal;
            list.Levels[2].NumberTextFormat = 3 + ".";
            
            list.Levels[3].NumberingStyle = NumberingStyle.None;
            list.Levels[3].NumberTextFormat = "";
            list.Levels[3].ParagraphProperties.LeftIndent.LocalValue = 48;
            
            list.Levels[4].NumberingStyle = NumberingStyle.Bullet;
            list.Levels[4].NumberTextFormat = "o";
            list.Levels[4].ParagraphProperties.LeftIndent.LocalValue = 48;
            
            #endregion
            
            #region Item 1
            
            Paragraph posIdentificationParagraph = section.Blocks.AddParagraph();
            Run posIdentificationListItem = posIdentificationParagraph.Inlines.AddRun("Position Identification");
            posIdentificationListItem.FontWeight = FontWeights.Bold;
            posIdentificationParagraph.ListId = list.Id;
            posIdentificationParagraph.ListLevel = 0;
            
            Table posIdentificationTable = new Table(document);
            posIdentificationTable.Indent = 60;
         
            section.Blocks.Add(posIdentificationTable);           

            for (int i = 0; i < tableData.GetLength(0); i++)
            {
                TableRow row = posIdentificationTable.Rows.AddTableRow();

                for (int j = 0; j < tableData.GetLength(1); j++)
                {
                    TableCell cell = row.Cells.AddTableCell();
                    cell.Blocks.AddParagraph().Inlines.AddRun(tableData[i, j]);                  
                    cell.PreferredWidth = new TableWidthUnit(200);
                }
            }       
            
            #endregion
            
            #region Item 2

            Paragraph posDescriptionTitle = section.Blocks.AddParagraph();
            var posDescriptionItem = posDescriptionTitle.Inlines.AddRun("Position description");
            
            posDescriptionItem.FontWeight = FontWeights.Bold;
            posDescriptionTitle.ListId = list.Id;        
            posDescriptionTitle.ListLevel = 1;

            Paragraph posDescriptionText = section.Blocks.AddParagraph();
            var posDescriptionTextPart1 = posDescriptionText.Inlines.AddRun(desripionPart1);
          
            editor.MoveToInlineEnd(posDescriptionTextPart1);
            editor.InsertHyperlink("Sitefinity CMS", "http://www.sitefinity.com/", false, "Sitefinity official site");
            
            posDescriptionText.Inlines.AddRun(desripionPart2);
            posDescriptionText.ListId = list.Id;
            posDescriptionText.ListLevel = 3;
            
            #endregion
            
            #region Item 3
            
            Paragraph competenciesRequiredText = section.Blocks.AddParagraph();
            Run competenciesRequiredItem = competenciesRequiredText.Inlines.AddRun("Competencies required");
            competenciesRequiredItem.FontWeight = FontWeights.Bold;
            competenciesRequiredText.ListId = list.Id;
            competenciesRequiredText.ListLevel = 2;
                
            for (int i = 0; i < competencies.Length; i++)
            {
                Paragraph itemText = section.Blocks.AddParagraph();
                itemText.Inlines.AddRun(competencies[i]);
                itemText.ListId = list.Id;
                itemText.ListLevel = 4;
            }
            
            #endregion

            #region Export 
            using (Stream output = new FileStream(@"..\..\output.docx", FileMode.Create))
            {
                DocxFormatProvider provider = new DocxFormatProvider();
                provider.Export(document, output);
            }

            #endregion

            Process.Start(@"..\..\output.docx");
            radLabel1.Text = "File saved to: " + Path.GetFullPath(@"..\..\output.docx");
        }
        #region data
        string desripionPart1 = @"Telerik is currently seeking a detail oriented Technical Support Officer to join our ";
        string desripionPart2 = @" team in Sofia, Bulgaria. The Technical Support Officer will communicate directly with customers as well as serve as a technical resource for members of the sales team by addressing client’s complex technical inquiries.
 Relying on your background with ASP.NET / Web technologies and past experiences in client facing roles, your main duty will be to provide timely support to customers and members of the sales team over the phone, our online ticketing system, or email. You will need to analyze, track and resolve customer’s technical problems in a considerate and professional manner, and communicate closely with the appropriate development team. 
The ideal candidate will be able to quickly solve problems that involve a broad range of technical skills with an emphasis on the ASP.NET Framework and experience with CMS products such as Telerik’s Sitefinity ASP.NET CMS. You will be dealing mainly with developers and should be speaking with them on highly technical topics.
";
        string[] competencies = new string[]
        {
            "Technical background in ASP.NET Microsoft platform (WebForms and MVC)",
            "Programming experience with LINQ, C#, and JavaScript",
            "Experience with HTML and CSS",
            "Experience with Networks, Hosting environments, IIS",
            "Experience with Microsoft SQL Server 2008/2012 is a plus",
            "Experience with ORM Framework is a plus",
            "Previous professional experience on a technical support related position",
            "Bachelor's degree in Computer Science or relevant field",
            "Exceptional problem-solving skills",
            "Exceptional ability to learn new skills",
            "Excellent communication skills: listening, written and verbal",
            "Strong work ethics and time management skills"
        };
        
        string[,] tableData = new string[,]
        {
            { "Title", "Technical Support Officer" },
            { "Functional area", "Sitefinity CMS" },
            { "Reports to", "Sitefinity Team Leader" },
            { "Employment status", "Full-time job" }
        };
        #endregion
    }
}